NVIDIA-CURAND
=============

**WARNING:** This project is not functional and is a placeholder from NVIDIA.
Please refer to the documentation: https://github.com/NVIDIA/tensorflow#install

.. code-block:: bash

    pip install nvidia-pyindex
    pip install nvidia-curand